/*--------------------------------------------------------------------------
  CMS8S5880.H
 Registers definition for CMS8S5880

Copyright CMS Semicon Co., Ltd
 All rights reserved.
-------------------------------------------------------------------------- */
#ifndef _CMS8S5880XX_H_
#define _CMS8S5880XX_H_

#include "intrins.h"

/**********************************************************/
/**
 * IO definitions
 *
 * define access restrictions to peripheral registers
 */
#define     __I     volatile const   /*!< defines 'read only' permissions     */
#define     __O     volatile         /*!< defines 'write only' permissions    */
#define     __IO    volatile         /*!< defines 'read / write' permissions  */

typedef   signed char     int8_t;
typedef   signed short    int16_t;
typedef   signed long     int32_t;

typedef unsigned char     uint8_t;
typedef unsigned short    uint16_t;
typedef unsigned long     uint32_t;

typedef int32_t  s32;
typedef int16_t s16;
typedef int8_t  s8;

typedef uint32_t  u32;
typedef uint16_t u16;
typedef uint8_t  u8;


typedef enum
{
	FALSE = 0, 
	TRUE = 1
}bool;

typedef enum
{
	RESET = 0, 
	SET = 1
}FlagStatus, ITStatus, BitStatus, BitAction;

typedef enum{DISABLE = 0, ENABLE = !DISABLE} FunctionalState;
#define IS_FUNCTIONALSTATE_OK(STATE) (((STATE) == DISABLE) || ((STATE) == ENABLE))

typedef enum {ERROR = 0, SUCCESS = !ERROR} ErrorStatus;

#define U8_MAX     (255)
#define S8_MAX     (127)
#define S8_MIN     (-128)
#define U16_MAX    (65535uL)
#define S16_MAX    (32767)
#define S16_MIN    (-32768)
#define U32_MAX    (4294967295uL)
#define S32_MAX    (2147483647)
#define S32_MIN    (-2147483648uL)

	
/* *********************************************************************** */
/* *********************************************************************** */

/*---------------------------------------------------------------------------
  Defined registers  
---------------------------------------------------------------------------*/

/*  BYTE Register  */
	sfr P0        = 0x80; /* Port 0                    */
	sfr SP        = 0x81;
	sfr DPL0      = 0x82;
	sfr DPH0      = 0x83;
	sfr DPL1      = 0x84; /* Data Pointer 1 Low byte   */
	sfr DPH1      = 0x85; /* Data Pointer 1 High byte  */
	sfr DPS       = 0x86; /* Data pointers select      */
	sfr PCON      = 0x87;   /* Power Configuration       */
	sfr TCON      = 0x88;   /* Timer 0,1 Configuration   */
	sfr TMOD      = 0x89; /* Timer 0,1 Mode            */
	sfr TL0       = 0x8A; /* Timer 0 Low byte counter  */
	sfr TL1       = 0x8B; /* Timer 1 Low byte counter  */
	sfr TH0       = 0x8C; /* Timer 0 High byte counter */
	sfr TH1       = 0x8D; /* Timer 1 High byte counter */
	sfr CKCON     = 0x8E;   /* XDATA Wait States         */
	sfr CLKDIV    = 0x8F;   /* CPU Clock Setup         */
	sfr P1        = 0x90; /* Port 1                    */
	sfr FUNCCR    = 0x91;   /* */

	sfr DPX0      = 0x93; /* Data Page Pointer 0       */

	sfr DPX1      = 0x95; /* Data Page Pointer 1       */
	sfr TA        = 0x96; /* Timed Access protection   */
	sfr WDCON     = 0x97; /* Watchdog configuration    */
	sfr WDTCON    = 0x97; /* Watchdog configuration    */	
	sfr SCON      = 0x98; /* Serial 0 Configuration    */
	sfr SCON0     = 0x98;
	sfr SBUF      = 0x99; /* Serial 0 I/O Buffer       */
	sfr SBUF0     = 0x99;
	sfr P0TRIS    = 0x9A; /*                    */
	sfr P2        = 0xA0; /* Port 2                    */
	sfr P1TRIS    = 0xA1; /*                    */
	sfr P2TRIS    = 0xA2; /*                    */
	sfr P3TRIS    = 0xA3; /*                    */
	sfr IE        = 0xA8;   /* Interrupt Enable          */

	sfr EIE2      = 0xAA;   /* External Interrupt Enable */
	sfr P0EXTIE		= 0xAC;
	sfr P1EXTIE		= 0xAD;
	sfr P2EXTIE		= 0xAE;
	sfr P3EXTIE 	= 0xAF;
	sfr	P3				= 0xB0;

	sfr EIF2			= 0xB2;

	sfr P0EXTIF   = 0xB4;   /* P0 Ports External Interrupt Flag */
	sfr P1EXTIF   = 0xB5;   /* P1 Ports External Interrupt Flag */
	sfr P2EXTIF   = 0xB6;   /* P2 Ports External Interrupt Flag */
	sfr P3EXTIF   = 0xB7;   /* P3 Ports External Interrupt Flag */

	sfr IP        = 0xB8;
	sfr EIP1      = 0xB9; /* External Interr. Priority */
	sfr EIP2      = 0xBA; /* External Interr. Priority */

	sfr WUTCRL     = 0xBC; /*                    */
	sfr WUTCRH     = 0xBD; /*                    */	
	sfr BUZDIV    = 0xBE; /*                    */
	sfr BUZCON    = 0xBF; /*                    */
	sfr CCL1    	= 0xC2;  /* Comare/Capture/Reload 1 Low */
	sfr CCH1     	= 0xC3;  /* Comare/Capture/Reload 1 High*/
	sfr CCL2     	= 0xC4;  /* Comare/Capture/Reload 2 Low */
	sfr CCH2     	= 0xC5;  /* Comare/Capture/Reload 2 High*/
	sfr CCL3     	= 0xC6;  /* Comare/Capture/Reload 3 Low */
	sfr CCH3     	= 0xC7;  /* Comare/Capture/Reload 3 High*/
	sfr T2CON     = 0xC8; /* Timer 2 Configuration     */
	sfr T2IF      = 0xC9; /* Timer 2 Interrupt Flags   */
	sfr RLDL      = 0xCA; /* Timer 2 Reload Low byte   */
	sfr RLDH      = 0xCB; /* Timer 2 Reload High byte  */
	sfr TL2       = 0xCC; /* Timer 2 Low byte counter  */
	sfr TH2       = 0xCD; /* Timer 2 High byte counter */
	sfr CCEN      = 0xCE; /* Comare/Capture/Reload Enable*/
	sfr T2IE      = 0xCF; 

	sfr PSW       = 0xD0;   /* Program Status Word       */
	sfr ADCMPC		= 0xD1;	
	sfr T34MOD		= 0xD2;	
	sfr ADDLYL		= 0xD3;	
	sfr ADCMPL		= 0xD4;	
	sfr ADCMPH		= 0xD5;	
	sfr CAPCR0		= 0xD6; 
	sfr CAPCR1		= 0xD7;   
	sfr TL3				= 0xDA;	
	sfr TH3				= 0xDB;		
	sfr ADRESL    = 0xDC; /* ADC result high 8-bit    */
	sfr ADRESH    = 0xDD; /* ADC result low 8-bit    */
	sfr ADCON1    = 0xDE; /* ADC control 1    */
	sfr ADCON0    = 0xDF; /* ADC control 0    */
	sfr ACC       = 0xE0;   /* Accumulator               */
	sfr TL4				= 0xE2;	
	sfr TH4				= 0xE3;		
	sfr ADCON2		= 0xE9;	
	sfr SCON1     = 0xEA; /* Serial 1 Configuration    */
	sfr SBUF1     = 0xEB;
	sfr SPCR      = 0xEC; /* SPI Control Register      */
	sfr SPSR      = 0xED; /* SPI Status Register       */
	sfr SPDR      = 0xEE; /* SPI I/O Register          */
	sfr SSCR      = 0xEF; /* SPI Sleve Select Register */
	sfr B         = 0xF0;   /* B Working register        */
	sfr I2CSADR 	= 0xF1;   /* I2CS Address              */
	sfr I2CSCR  	= 0xF2;   /* I2CS Control Register     */
	sfr I2CSBUF 	= 0xF3;   /* I2CS I/O Buffer           */
	sfr I2CMSA   	= 0xF4;  /* I2CM Slave Address        */
	sfr I2CMCR   	= 0xF5;  /* I2CM Control Register     */
	sfr I2CMSR   	= 0xF5;  /* I2CM Control Register     */
	sfr I2CMBUF  	= 0xF6;  /* I2CM I/O Buffer           */
	sfr I2CMTP   	= 0xF7;  /* I2CM Timer Period         */
	sfr MAIN_LOCK   = 0xFB;
	sfr MADRL			= 0xFC;
	sfr MADRH			= 0xFD;
	sfr MDATA			= 0xFE;
	sfr MCTRL			= 0xFF;


/*-------------------------------------------------------------------------*/
/*	sfr 16 */
/*-------------------------------------------------------------------------*/


	sfr16	T2	= 0xCC;		// {T2L,T2H}
	sfr16	DPTR0 = 0x82;				  //********++++//
	sfr16	DPTR1 = 0x84;				  //********++++//
	sfr16	CC1	= 0xC2;		// {CCL1,CCH1}
	sfr16	CC2	= 0xC4;		// {CCL2,CCH2}
	sfr16	CC3	= 0xC6;		// {CCL3,CCH3}
	sfr16	RCR	= 0xCA;		// {RCRL,RCRH}
	sfr16	RLD	= 0xCA;		// {RCRL,RCRH}
	sfr16 	ADCMP = 0xD4;  //{ADCMPL.ADCMPH}
	sfr16	ADRES	= 0xDC;		// {ADRESL,ADRESH}

	sfr16	MADR	= 0xFC;		// {MADRL,MADRH}
/*-------------------------------------------------------------------------*/
/*	XSFR */
/*-------------------------------------------------------------------------*/

#define P04CFG *(volatile unsigned char xdata *) 0xF004
#define P05CFG *(volatile unsigned char xdata *) 0xF005

#define P0OD *(volatile unsigned char xdata *) 0xF009
#define P0UP *(volatile unsigned char xdata *) 0xF00A
#define P0RD	*(volatile unsigned char xdata *) 0xF00B
//#define P0DR	*(volatile unsigned char xdata *) 0xF00C
//#define P0SR	*(volatile unsigned char xdata *) 0xF00D
	

#define P13CFG *(volatile unsigned char xdata *) 0xF013
#define P14CFG *(volatile unsigned char xdata *) 0xF014
#define P15CFG *(volatile unsigned char xdata *) 0xF015
#define P16CFG *(volatile unsigned char xdata *) 0xF016
#define P17CFG *(volatile unsigned char xdata *) 0xF017
//#define P1ANS *(volatile unsigned char xdata *) 0xF018
#define P1OD *(volatile unsigned char xdata *) 0xF019
#define P1UP *(volatile unsigned char xdata *) 0xF01A
#define P1RD	*(volatile unsigned char xdata *) 0xF01B

#define P21CFG *(volatile unsigned char xdata *) 0xF021
#define P22CFG *(volatile unsigned char xdata *) 0xF022
#define P23CFG *(volatile unsigned char xdata *) 0xF023
#define P24CFG *(volatile unsigned char xdata *) 0xF024
#define P25CFG *(volatile unsigned char xdata *) 0xF025
#define P26CFG *(volatile unsigned char xdata *) 0xF026

#define P2OD *(volatile unsigned char xdata *) 0xF029
#define P2UP *(volatile unsigned char xdata *) 0xF02A
#define P2RD	*(volatile unsigned char xdata *) 0xF02B


#define P30CFG *(volatile unsigned char xdata *) 0xF030
#define P31CFG *(volatile unsigned char xdata *) 0xF031
#define P32CFG *(volatile unsigned char xdata *) 0xF032

#define P35CFG *(volatile unsigned char xdata *) 0xF035
#define P36CFG *(volatile unsigned char xdata *) 0xF036

#define P3OD *(volatile unsigned char xdata *) 0xF039
#define P3UP *(volatile unsigned char xdata *) 0xF03A
#define P3RD	*(volatile unsigned char xdata *) 0xF03B



#define P04EICFG *(volatile unsigned char xdata *) 0xF084
#define P05EICFG *(volatile unsigned char xdata *) 0xF085

#define P13EICFG *(volatile unsigned char xdata *) 0xF08B
#define P14EICFG *(volatile unsigned char xdata *) 0xF08C
#define P15EICFG *(volatile unsigned char xdata *) 0xF08D
#define P16EICFG *(volatile unsigned char xdata *) 0xF08E
#define P17EICFG *(volatile unsigned char xdata *) 0xF08F

#define P21EICFG *(volatile unsigned char xdata *) 0xF091
#define P22EICFG *(volatile unsigned char xdata *) 0xF092
#define P23EICFG *(volatile unsigned char xdata *) 0xF093
#define P24EICFG *(volatile unsigned char xdata *) 0xF094
#define P25EICFG *(volatile unsigned char xdata *) 0xF095
#define P26EICFG *(volatile unsigned char xdata *) 0xF096


#define P30EICFG *(volatile unsigned char xdata *) 0xF098
#define P31EICFG *(volatile unsigned char xdata *) 0xF099
#define P32EICFG *(volatile unsigned char xdata *) 0xF09A

#define P35EICFG *(volatile unsigned char xdata *) 0xF09D
#define P36EICFG *(volatile unsigned char xdata *) 0xF09E


#define PWMCON		*(volatile unsigned char xdata *) 0xF120
#define PWMOE			*(volatile unsigned char xdata *) 0xF121  
#define PWMPINV		*(volatile unsigned char xdata *) 0xF122  
#define PWM01PSC	*(volatile unsigned char xdata *) 0xF123  
#define PWM23PSC	*(volatile unsigned char xdata *) 0xF124  
#define PWM45PSC	*(volatile unsigned char xdata *) 0xF125  
#define PWMCNTE		*(volatile unsigned char xdata *) 0xF126  
#define PWMCNTM		*(volatile unsigned char xdata *) 0xF127  
#define PWMCNTCLR	*(volatile unsigned char xdata *) 0xF128  
#define PWMLOADEN	*(volatile unsigned char xdata *) 0xF129  
	
#define PWM0DIV		*(volatile unsigned char xdata *) 0xF12A  
#define PWM1DIV		*(volatile unsigned char xdata *) 0xF12B  
#define PWM2DIV		*(volatile unsigned char xdata *) 0xF12C  
#define PWM3DIV		*(volatile unsigned char xdata *) 0xF12D  
#define PWM4DIV		*(volatile unsigned char xdata *) 0xF12E  
#define PWM5DIV		*(volatile unsigned char xdata *) 0xF12F  

#define PWMP0L		*(volatile unsigned char xdata *) 0xF130  
#define PWMP0H		*(volatile unsigned char xdata *) 0xF131 
#define PWMP1L		*(volatile unsigned char xdata *) 0xF132 
#define PWMP1H		*(volatile unsigned char xdata *) 0xF133 
#define PWMP2L		*(volatile unsigned char xdata *) 0xF134 
#define PWMP2H		*(volatile unsigned char xdata *) 0xF135 
#define PWMP3L		*(volatile unsigned char xdata *) 0xF136 
#define PWMP3H		*(volatile unsigned char xdata *) 0xF137 
#define PWMP4L		*(volatile unsigned char xdata *) 0xF138 
#define PWMP4H		*(volatile unsigned char xdata *) 0xF139 
#define PWMP5L		*(volatile unsigned char xdata *) 0xF13A 
#define PWMP5H		*(volatile unsigned char xdata *) 0xF13B 

#define PWMD0L		*(volatile unsigned char xdata *) 0xF140  
#define PWMD0H		*(volatile unsigned char xdata *) 0xF141 
#define PWMD1L		*(volatile unsigned char xdata *) 0xF142 
#define PWMD1H		*(volatile unsigned char xdata *) 0xF143 
#define PWMD2L		*(volatile unsigned char xdata *) 0xF144 
#define PWMD2H		*(volatile unsigned char xdata *) 0xF145 
#define PWMD3L		*(volatile unsigned char xdata *) 0xF146 
#define PWMD3H		*(volatile unsigned char xdata *) 0xF147 
#define PWMD4L		*(volatile unsigned char xdata *) 0xF148 
#define PWMD4H		*(volatile unsigned char xdata *) 0xF149 
#define PWMD5L		*(volatile unsigned char xdata *) 0xF14A 
#define PWMD5H		*(volatile unsigned char xdata *) 0xF14B   

#define PWMDD0L		*(volatile unsigned char xdata *) 0xF150  
#define PWMDD0H		*(volatile unsigned char xdata *) 0xF151 
#define PWMDD1L		*(volatile unsigned char xdata *) 0xF152 
#define PWMDD1H		*(volatile unsigned char xdata *) 0xF153 
#define PWMDD2L		*(volatile unsigned char xdata *) 0xF154 
#define PWMDD2H		*(volatile unsigned char xdata *) 0xF155 
#define PWMDD3L		*(volatile unsigned char xdata *) 0xF156 
#define PWMDD3H		*(volatile unsigned char xdata *) 0xF157 
#define PWMDD4L		*(volatile unsigned char xdata *) 0xF158 
#define PWMDD4H		*(volatile unsigned char xdata *) 0xF159 
#define PWMDD5L		*(volatile unsigned char xdata *) 0xF15A 
#define PWMDD5H		*(volatile unsigned char xdata *) 0xF15B   

#define PWMDTE		*(volatile unsigned char xdata *) 0xF160 
#define PWM01DT		*(volatile unsigned char xdata *) 0xF161 
#define PWM23DT		*(volatile unsigned char xdata *) 0xF162
#define PWM45DT		*(volatile unsigned char xdata *) 0xF163 
	
#define PWMMASKE	*(volatile unsigned char xdata *) 0xF164 
#define PWMMASKD	*(volatile unsigned char xdata *) 0xF165 
#define PWMFBKC		*(volatile unsigned char xdata *) 0xF166 
#define PWMFBKD		*(volatile unsigned char xdata *) 0xF167 
	
#define PWMPIE		*(volatile unsigned char xdata *) 0xF168   
#define PWMZIE		*(volatile unsigned char xdata *) 0xF169   
#define PWMUIE		*(volatile unsigned char xdata *) 0xF16A   
#define PWMDIE		*(volatile unsigned char xdata *) 0xF16B   
#define PWMPIF		*(volatile unsigned char xdata *) 0xF16C   
#define PWMZIF		*(volatile unsigned char xdata *) 0xF16D   
#define PWMUIF		*(volatile unsigned char xdata *) 0xF16E   
#define PWMDIF		*(volatile unsigned char xdata *) 0xF16F



#define BRTCON		*(volatile unsigned char xdata *) 0xF5C0
#define BRTDL		*(volatile unsigned char xdata *) 0xF5C1
#define BRTDH		*(volatile unsigned char xdata *) 0xF5C2

#define UID0		*(volatile unsigned char xdata *) 0xF5E0 
#define UID1		*(volatile unsigned char xdata *) 0xF5E1 
#define UID2		*(volatile unsigned char xdata *) 0xF5E2
#define UID3		*(volatile unsigned char xdata *) 0xF5E3
#define UID4		*(volatile unsigned char xdata *) 0xF5E4
#define UID5		*(volatile unsigned char xdata *) 0xF5E5
#define UID6		*(volatile unsigned char xdata *) 0xF5E6 
#define UID7		*(volatile unsigned char xdata *) 0xF5E7 
#define UID8		*(volatile unsigned char xdata *) 0xF5E8
#define UID9		*(volatile unsigned char xdata *) 0xF5E9
#define UID10		*(volatile unsigned char xdata *) 0xF5EA
#define UID11		*(volatile unsigned char xdata *) 0xF5EB



	
/*-------------------------------------------------------------------------
  BIT Register  
  -------------------------------------------------------------------------*/

/*  P0  */

//  sbit P07     = P0^7;
//  sbit P06     = P0^6;
  sbit P05     = P0^5;
  sbit P04     = P0^4;
//  sbit P03     = P0^3;
//  sbit P02     = P0^2;
//  sbit P01     = P0^1;
//  sbit P00     = P0^0;


/*  P1  */

  sbit P17     = P1^7;
  sbit P16     = P1^6;
  sbit P15     = P1^5;
  sbit P14     = P1^4;
  sbit P13     = P1^3;
//  sbit P12     = P1^2;
//  sbit P11     = P1^1;
//  sbit P10     = P1^0;
/*  P2  */
//  sbit P27     = P2^7;
  sbit P26     = P2^6;
  sbit P25     = P2^5;
  sbit P24     = P2^4;
  sbit P23     = P2^3;
  sbit P22     = P2^2;
  sbit P21     = P2^1;
//  sbit P20     = P2^0;
/*  P3  */
//  sbit P37     = P3^7;
  sbit P36     = P3^6;
  sbit P35     = P3^5;
//  sbit P34     = P3^4;
//  sbit P33     = P3^3;
  sbit P32     = P3^2;
  sbit P31     = P3^1;
  sbit P30     = P3^0;
  
/*  TCON  */
  sbit IT0      = TCON^0;
  sbit IE0      = TCON^1;
  sbit IT1      = TCON^2;
  sbit IE1      = TCON^3;
  sbit TR0      = TCON^4;
  sbit TF0      = TCON^5;
  sbit TR1      = TCON^6;
  sbit TF1      = TCON^7;


/*  SCON0 */

  sbit RI0      = SCON0^0;
  sbit TI0      = SCON0^1;
  sbit U0RB8    = SCON0^2;
  sbit U0TB8    = SCON0^3;
  sbit U0REN    = SCON0^4;
  sbit U0SM2    = SCON0^5;
  sbit U0SM1    = SCON0^6;
  sbit U0SM0    = SCON0^7;

  sbit RB08     = SCON0^2;
  sbit TB08     = SCON0^3;
  sbit REN0     = SCON0^4;
  sbit SM02     = SCON0^5;
  sbit SM01     = SCON0^6;
  sbit SM00     = SCON0^7;
  
  /*  IE */
  sbit EX0     	= IE^0;
  sbit ET0     	= IE^1;
  sbit EX1     	= IE^2;
  sbit ET1     	= IE^3;
  sbit ES0     	= IE^4;
  sbit ET2     	= IE^5;
  sbit ES1     	= IE^6;
  sbit EA      	= IE^7;
  
  
    /*  IP */
  sbit PX0     	= IP^0;
  sbit PT0     	= IP^1;
  sbit PX1     	= IP^2;
  sbit PT1     	= IP^3;
  sbit PS0     	= IP^4;
  sbit PT2     	= IP^5;
  sbit PS1     	= IP^6;
  
    /*  T2CON */
  sbit T2I0     = T2CON^0;
  sbit T2I1     = T2CON^1;
  sbit T2CM     = T2CON^2;
  sbit T2R0     = T2CON^3;
  sbit T2R1     = T2CON^4;
  sbit CAPES	= T2CON^5;/////
  sbit I3FR     = T2CON^6;
  sbit T2PS     = T2CON^7;
  
    /* PSW  */
  sbit  P     	=PSW^0;

  sbit  OV    	=PSW^2;
  sbit  RS0   	=PSW^3;
  sbit  RS1    	=PSW^4;
  sbit  F0    	=PSW^5;
  sbit  AC    	=PSW^6;
  sbit  CY    	=PSW^7;
  
/****************************************************************************************/ 
/* PCON Bit Values */
#define IDLE   		0x01
#define STOP  		0x02
#define SWE   		0x04

#define SMOD1   	0x40
#define SMOD0 		0x80

/* TMOD Bit Values */
#define T0M0  	 	0x01
#define T0M1  	 	0x02
#define CT0  	 		0x04
#define GATE0 	 	0x08
#define T1M0  	 	0x10
#define T1M1  	 	0x20
#define CT1   		0x40
#define GATE1 		0x80

/* CKCON Bit Values */

#define T0M 	 		0x08
#define T1M   	 	0x10
#define WTS0		0x40
 #define WTS1		0x80
 
 
 /* FUNCCR Bit Values */
#define UART0_CKS 0x01
#define UART1_CKS 0x02
#define UART0_CKS1	0x04
#define UART1_CKS1  0x08
#define I2C_PORTS 0x10
#define UART1_PORTS 0x20


 /* WDTCON Bit Values */
#define	WDTCLR		0x01
#define	WDTRE			0x02
#define	WDTRF			0x04
#define	WDTIF			0x08

#define	PORF			0x40
#define	SWRST			0x80

 /* EIE2 Bit Values */
#define	ET3				0x01
#define	ET4				0x02

#define	PWMIE			0x08
#define	ADCIE			0x10
#define	WDTIE			0x20
#define	I2CIE			0x40
#define	SPIIE			0x80 

 /* EIF2 Bit Values */
#define	TF3				0x01
#define	TF4				0x02

#define	PWMIF			0x08
#define	ADCIF			0x10

#define	I2CIF			0x40
#define	SPIIF			0x80 

 /* EIP1 Bit Values */
#define	PP0				0x01
#define	PP1				0x02
#define	PP2				0x04
//#define	PP3PWM		0x08
#define	PP3   		0x08

//#define	PACMP			0x80 

 /* EIP2 Bit Values */
#define	PT3				0x01
#define	PT4				0x02

#define	PPWM			0x08
#define	PADC			0x10
#define	PWDT			0x20
#define	PI2C			0x40
#define	PSPI			0x80 

 /* BUZCON Bit Values */
#define	BUZCKS0		0x01
#define	BUZCKS1		0x02

#define	BUZEN			0x80

 /* T2IF Bit Values */
#define	T2C0IF		0x01
#define	T2C1IF		0x02
#define	T2C2IF		0x04
#define	T2C3IF		0x08

#define	T2EXIF		0x40
#define	TF2				0x80

 /* T2IE Bit Values */
#define	T2C0IE		0x01
#define	T2C1IE		0x02
#define	T2C2IE		0x04
#define	T2C3IE		0x08

#define	T2EXIE		0x40
#define	T2OVIE		0x80 

 /* ADCMPC Bit Values */

#define	ADCMPO		0x10

#define	ADCMPPS		0x40
#define	ADFBEN		0x80 

 /* T34MOD Bit Values */
#define	T3M0			0x01
#define	T3M1			0x02
#define	T3M				0x04
#define	TR3				0x08
#define	T4M0			0x10
#define	T4M1			0x20
#define	T4M				0x40
#define	TR4				0x80 

 /* ADCON1 Bit Values */
#define	ADCHS0		0x01
#define	ADCHS1		0x02
#define	ADCHS2		0x04
#define	ADCHS3		0x08
#define	ADCKS0		0x10
#define	ADCKS1		0x20
#define	ADCKS2		0x40
#define	ADEN			0x80 

 /* ADCON0 Bit Values */

#define	ADGO			0x02

#define	AN15SEL0	0x10
#define	AN15SEL1	0x20
#define	ADFM			0x40

 /* ADCON2 Bit Values */

#define	ADEGS0		0x04
#define	ADEGS1		0x08
#define	ADTGS0		0x10
#define	ADTGS1		0x20
#define	ADCPX			0x40
#define	ADCEX			0x80

 /* SCON1 Bit Values */
#define	RI1				0x01
#define	TI1				0x02
#define	U1RB8			0x04
#define	U1TB8			0x08
#define	U1REN			0x10
#define	U1SM2			0x20
#define	U1SM1			0x40
#define	U1SM0			0x80

 /* SPCR Bit Values */
#define	SPR0			0x01
#define	SPR1			0x02
#define	CPHA			0x04
#define	CPOL			0x08
#define	MSTR			0x10
#define	SPR2			0x20
#define	SPEN			0x40

 /* SPSR Bit Values */
#define	SSCEN			0x01
#define	SSICS			0x02

//#define	MODF			0x10

#define	WCOL			0x40
#define	SPISIF		0x80

 /* SSCR Bit Values */

#define	SSO3			0x08

#define	SSO5			0x20
#define	SSO6			0x40
#define	SSO7			0x80

 /* I2CSCR Bit Values */
#define	DA				0x01

#define	RSTS			0x80

 /* I2CMCR Bit Values */
#define	I2C_G_RUN				0x01
#define	I2C_G_RSTART		0x02
#define	I2C_G_RSTOP			0x04
#define	I2C_G_RACK			0x08

 /* I2CMSR */
#define	I2C_F_BUSY			0x01
#define	I2C_F_ERROR			0x02
#define	I2C_F_ADD_ACK		0x04
#define	I2C_F_DATA_ACK	0x08
#define	I2C_F_ARB_LOST	0x10
#define	I2C_F_IDLE			0x20
#define	I2C_F_BUS_BUSY	0x40
#define	I2C_F_I2CMIF		0x80

//----------------------------------------------------
//----------------------------------------------------
#define _nop2_()					_nop_(), _nop_()
#define _nop3_()					_nop_(), _nop2_()
#define _nop4_()					_nop_(), _nop3_()	
#define _nop5_()					_nop_(), _nop4_()	
#define _nop6_()					_nop_(), _nop5_()		

#define clrwdt()					TA=0xAA, TA=0x55, WDTCON=0x01;

#define software_reset_system()		TA=0xAA, TA=0x55, WDTCON=0x80;	

#define idle()						_nop6_(), PCON=PCON|0x01, _nop6_()
#define sleep()						_nop6_(), PCON=PCON|0x06, _nop6_()	
#define stop()						_nop6_(), PCON=PCON|0x06, _nop6_()
#define stop_forever()		_nop6_(), PCON=PCON|0x02, _nop6_()

	
	
//----------------------------------------------------
//----------------------------------------------------
   
  
/* DSPI Select Codes For SSCR register                         */
#define SEL_7               0x80
#define SEL_6               0x40
#define SEL_5               0x20
#define SEL_4               0x10
#define SEL_3               0x08
#define SEL_2               0x04
#define SEL_1               0x02
#define SEL_0               0x01



/*-----------------------------------------------------------------
**	Peripheral memory map
------------------------------------------------------------------*/

/*-----------------------------------------------------------------
**IRQ ж 
------------------------------------------------------------------*/
/*------IE--------------------------------------------------------*/
#define IRQ_IE_EA_Pos			(7)
#define IRQ_IE_EA_Msk			(0x1 << IRQ_IE_EA_Pos)
#define IRQ_IE_ES1_Pos			(6)
#define IRQ_IE_ES1_Msk			(0x1 << IRQ_IE_ES1_Pos)
#define IRQ_IE_ET2_Pos			(5)
#define IRQ_IE_ET2_Msk			(0x1 << IRQ_IE_ET2_Pos)
#define IRQ_IE_ES0_Pos			(4)
#define IRQ_IE_ES0_Msk			(0x1 << IRQ_IE_ES0_Pos)
#define IRQ_IE_ET1_Pos			(3)
#define IRQ_IE_ET1_Msk			(0x1 << IRQ_IE_ET1_Pos)
#define IRQ_IE_EX1_Pos			(2)
#define IRQ_IE_EX1_Msk			(0x1 << IRQ_IE_EX1_Pos)
#define IRQ_IE_ET0_Pos			(1)
#define IRQ_IE_ET0_Msk			(0x1 << IRQ_IE_ET0_Pos)
#define IRQ_IE_EX0_Pos			(0)
#define IRQ_IE_EX0_Msk			(0x1 << IRQ_IE_EX0_Pos)
/*------EIE2------------------------------------------------------*/
#define IRQ_EIE2_SPIIE_Pos		(7)
#define IRQ_EIE2_SPIIE_Msk		(0x1 << IRQ_EIE2_SPIIE_Pos)
#define IRQ_EIE2_I2CIE_Pos		(6)
#define IRQ_EIE2_I2CIE_Msk		(0x1 << IRQ_EIE2_I2CIE_Pos)
#define IRQ_EIE2_WDTIE_Pos		(5)
#define IRQ_EIE2_WDTIE_Msk		(0x1 << IRQ_EIE2_WDTIE_Pos)
#define IRQ_EIE2_ADCIE_Pos		(4)
#define IRQ_EIE2_ADCIE_Msk		(0x1 << IRQ_EIE2_ADCIE_Pos)
#define IRQ_EIE2_PWMIE_Pos		(3)
#define IRQ_EIE2_PWMIE_Msk		(0x1 << IRQ_EIE2_PWMIE_Pos)
#define IRQ_EIE2_ET4IE_Pos		(1)
#define IRQ_EIE2_ET4IE_Msk		(0x1 << IRQ_EIE2_ET4IE_Pos)
#define IRQ_EIE2_ET3IE_Pos		(0)
#define IRQ_EIE2_ET3IE_Msk		(0x1 << IRQ_EIE2_ET3IE_Pos)
/*------EIF2------------------------------------------------------*/
#define IRQ_EIF2_SPIIF_Pos		(7)
#define IRQ_EIF2_SPIIF_Msk		(0x1 << IRQ_EIF2_SPIIF_Pos)
#define IRQ_EIF2_I2CIF_Pos		(6)
#define IRQ_EIF2_I2CIF_Msk		(0x1 << IRQ_EIF2_I2CIF_Pos)
#define IRQ_EIF2_ADCIF_Pos		(4)
#define IRQ_EIF2_ADCIF_Msk		(0x1 << IRQ_EIF2_ADCIF_Pos)
#define IRQ_EIF2_PWMIF_Pos		(3)
#define IRQ_EIF2_PWMIF_Msk		(0x1 << IRQ_EIF2_PWMIF_Pos)
#define IRQ_EIF2_TF4_Pos		(1)
#define IRQ_EIF2_TF4_Msk		(0x1 << IRQ_EIF2_TF4_Pos)
#define IRQ_EIF2_TF3_Pos		(0)
#define IRQ_EIF2_TF3_Msk		(0x1 << IRQ_EIF2_TF3_Pos)
/*------IP--------------------------------------------------------*/
#define IRQ_IP_PS1_Pos			(6)
#define IRQ_IP_PS1_Msk			(0x1 << IRQ_IP_PS1_Pos)
#define IRQ_IP_PT2_Pos			(5)
#define IRQ_IP_PT2_Msk			(0x1 << IRQ_IP_PT2_Pos)
#define IRQ_IP_PS0_Pos			(4)
#define IRQ_IP_PS0_Msk			(0x1 << IRQ_IP_PS0_Pos)
#define IRQ_IP_PT1_Pos			(3)
#define IRQ_IP_PT1_Msk			(0x1 << IRQ_IP_PT1_Pos)
#define IRQ_IP_PX1_Pos			(2)
#define IRQ_IP_PX1_Msk			(0x1 << IRQ_IP_PX1_Pos)
#define IRQ_IP_PT0_Pos			(1)
#define IRQ_IP_PT0_Msk			(0x1 << IRQ_IP_PT0_Pos)
#define IRQ_IP_PX0_Pos			(0)
#define IRQ_IP_PX0_Msk			(0x1 << IRQ_IP_PX0_Pos)
/*------T2IE------------------------------------------------------*/
#define IRQ_T2IE_T2OVIE_Pos		(7)
#define IRQ_T2IE_T2OVIE_Msk		(0x1 << IRQ_T2IE_T2OVIE_Pos)
#define IRQ_T2IE_T2EXIE_Pos		(6)
#define IRQ_T2IE_T2EXIE_Msk		(0x1 << IRQ_T2IE_T2EXIE_Pos)
#define IRQ_T2IE_T2C3IE_Pos		(3)
#define IRQ_T2IE_T2C3IE_Msk		(0x1 << IRQ_T2IE_T2C3IE_Pos)
#define IRQ_T2IE_T2C2IE_Pos		(2)
#define IRQ_T2IE_T2C2IE_Msk		(0x1 << IRQ_T2IE_T2C2IE_Pos)
#define IRQ_T2IE_T2C1IE_Pos		(1)
#define IRQ_T2IE_T2C1IE_Msk		(0x1 << IRQ_T2IE_T2C1IE_Pos)
#define IRQ_T2IE_T2C0IE_Pos		(0)
#define IRQ_T2IE_T2C0IE_Msk		(0x1 << IRQ_T2IE_T2C0IE_Pos)
/*------T2IF------------------------------------------------------*/
#define IRQ_T2IF_TF2_Pos		(7)
#define IRQ_T2IF_TF2_Msk		(0x1 << IRQ_T2IF_TF2_Pos)
#define IRQ_T2IF_T2EXIF_Pos		(6)
#define IRQ_T2IF_T2EXIF_Msk		(0x1 << IRQ_T2IF_T2EXIF_Pos)
#define IRQ_T2IF_T2C3IF_Pos		(3)
#define IRQ_T2IF_T2C3IF_Msk		(0x1 << IRQ_T2IF_T2C3IF_Pos)
#define IRQ_T2IF_T2C2IF_Pos		(2)
#define IRQ_T2IF_T2C2IF_Msk		(0x1 << IRQ_T2IF_T2C2IF_Pos)
#define IRQ_T2IF_T2C1IF_Pos		(1)
#define IRQ_T2IF_T2C1IF_Msk		(0x1 << IRQ_T2IF_T2C1IF_Pos)
#define IRQ_T2IF_T2C0IF_Pos		(0)
#define IRQ_T2IF_T2C0IF_Msk		(0x1 << IRQ_T2IF_T2C0IF_Pos)



/*-----------------------------------------------------------------
**EPWM  
------------------------------------------------------------------*/
/*------PWMDTE----------------------------------------------------*/
#define EPWM_PWMDTE_PWM45DTE_Pos		(2)
#define EPWM_PWMDTE_PWM45DTE_Msk		(0x1 << EPWM_PWMDTE_PWM45DTE_Pos)
#define EPWM_PWMDTE_PWM23DTE_Pos		(1)
#define EPWM_PWMDTE_PWM23DTE_Msk		(0x1 << EPWM_PWMDTE_PWM23DTE_Pos)
#define EPWM_PWMDTE_PWM01DTE_Pos		(0)
#define EPWM_PWMDTE_PWM01DTE_Msk		(0x1 << EPWM_PWMDTE_PWM01DTE_Pos)
/*------PWMFBKC----------------------------------------------------*/
#define EPWM_PWMFBKC_PWMFBIE_Pos		(7)
#define EPWM_PWMFBKC_PWMFBIE_Msk		(0x1 << EPWM_PWMFBKC_PWMFBIE_Pos)
#define EPWM_PWMFBKC_PWMFBF_Pos			(6)
#define EPWM_PWMFBKC_PWMFBF_Msk			(0x1 << EPWM_PWMFBKC_PWMFBF_Pos)
#define EPWM_PWMFBKC_PWMFBCCE_Pos		(5)
#define EPWM_PWMFBKC_PWMFBCCE_Msk		(0x1 << EPWM_PWMFBKC_PWMFBCCE_Pos)
#define EPWM_PWMFBKC_PWMFBKSW_Pos		(4)
#define EPWM_PWMFBKC_PWMFBKSW_Msk		(0x1 << EPWM_PWMFBKC_PWMFBKSW_Pos)
#define EPWM_PWMFBKC_PWMFB1ES_Pos		(3)
#define EPWM_PWMFBKC_PWMFB1ES_Msk		(0x1 << EPWM_PWMFBKC_PWMFB1ES_Pos)
#define EPWM_PWMFBKC_PWMFB1EN_Pos		(1)
#define EPWM_PWMFBKC_PWMFB1EN_Msk		(0x1 << EPWM_PWMFBKC_PWMFB1EN_Pos)

/*-----------------------------------------------------------------
**ADC  
------------------------------------------------------------------*/
/*------ADCON0----------------------------------------------------*/
#define ADC_ADCON0_ADCHS4_Pos		(7)
#define ADC_ADCON0_ADCHS4_Msk		(0x1 << ADC_ADCON0_ADCHS4_Pos)
#define ADC_ADCON0_ADFM_Pos			(6)
#define ADC_ADCON0_ADFM_Msk			(0x1 << ADC_ADCON0_ADFM_Pos)
#define ADC_ADCON0_AN15SEL_Pos		(4)
#define ADC_ADCON0_AN15SEL_Msk		(0x3 << ADC_ADCON0_AN15SEL_Pos)
#define ADC_ADCON0_ADGO_Pos			(1)
#define ADC_ADCON0_ADGO_Msk			(0x1 << ADC_ADCON0_ADGO_Pos)
/*------ADCON1----------------------------------------------------*/
#define ADC_ADCON1_ADEN_Pos			(7)
#define ADC_ADCON1_ADEN_Msk			(0x1 << ADC_ADCON1_ADEN_Pos)
#define ADC_ADCON1_ADCKS_Pos		(4)
#define ADC_ADCON1_ADCKS_Msk		(0x7 << ADC_ADCON1_ADCKS_Pos)
#define ADC_ADCON1_ADCHS_Pos		(0)
#define ADC_ADCON1_ADCHS_Msk		(0xF << ADC_ADCON1_ADCHS_Pos)
/*------ADCON2----------------------------------------------------*/
#define ADC_ADCON2_ADCEX_Pos		(7)
#define ADC_ADCON2_ADCEX_Msk		(0x1 << ADC_ADCON2_ADCEX_Pos)
#define ADC_ADCON2_ADCPX_Pos		(6)
#define ADC_ADCON2_ADCPX_Msk		(0x1 << ADC_ADCON2_ADCPX_Pos)
#define ADC_ADCON2_ADTGS_Pos		(4)
#define ADC_ADCON2_ADTGS_Msk		(0x3 << ADC_ADCON2_ADTGS_Pos)
#define ADC_ADCON2_ADEGS_Pos		(2)
#define ADC_ADCON2_ADEGS_Msk		(0x3 << ADC_ADCON2_ADEGS_Pos)
/*------ADCMPC----------------------------------------------------*/
#define ADC_ADCMPC_ADFBEN_Pos		(7)
#define ADC_ADCMPC_ADFBEN_Msk		(0x1 << ADC_ADCMPC_ADFBEN_Pos)
#define ADC_ADCMPC_ADCMPPS_Pos		(6)
#define ADC_ADCMPC_ADCMPPS_Msk		(0x1 << ADC_ADCMPC_ADCMPPS_Pos)
#define ADC_ADCMPC_ADCMPO_Pos		(4)
#define ADC_ADCMPC_ADCMPO_Msk		(0x1 << ADC_ADCMPC_ADCMPO_Pos)
#define ADC_ADCMPC_ADDLY_Pos		(0)
#define ADC_ADCMPC_ADDLY_Msk		(0x3 << ADC_ADCMPC_ADDLY_Pos)

/*-----------------------------------------------------------------
**Timer
------------------------------------------------------------------*/
/*------TMOD------------------------------------------------------*/
#define TMR_TMOD_GATE1_Pos				(7)
#define TMR_TMOD_GATE1_Msk				(0x1 << TMR_TMOD_GATE1_Pos)
#define TMR_TMOD_CT1_Pos				(6)
#define TMR_TMOD_CT1_Msk				(0x1 << TMR_TMOD_CT1_Pos)
#define TMR_TMOD_T1Mn_Pos				(4)
#define TMR_TMOD_T1Mn_Msk				(0x3 << TMR_TMOD_T1Mn_Pos)
#define TMR_TMOD_GATE0_Pos				(3)
#define TMR_TMOD_GATE0_Msk				(0x1 << TMR_TMOD_GATE0_Pos)
#define TMR_TMOD_CT0_Pos				(2)
#define TMR_TMOD_CT0_Msk				(0x1 << TMR_TMOD_CT0_Pos)
#define TMR_TMOD_T0Mn_Pos				(0)
#define TMR_TMOD_T0Mn_Msk				(0x3 << TMR_TMOD_T0Mn_Pos)
/*------TCON------------------------------------------------------*/
#define TMR_TCON_TF1_Pos				(7)
#define TMR_TCON_TF1_Msk				(0x1 << TMR_TCON_TF1_Pos)
#define TMR_TCON_TR1_Pos				(6)
#define TMR_TCON_TR1_Msk				(0x1 << TMR_TCON_TR1_Pos)
#define TMR_TCON_TF0_Pos				(5)
#define TMR_TCON_TF0_Msk				(0x1 << TMR_TCON_TF0_Pos)
#define TMR_TCON_TR0_Pos				(4)
#define TMR_TCON_TR0_Msk				(0x1 << TMR_TCON_TR0_Pos)
#define TMR_TCON_IE1_Pos				(3)
#define TMR_TCON_IE1_Msk				(0x1 << TMR_TCON_IE1_Pos)
#define TMR_TCON_IT1_Pos				(2)
#define TMR_TCON_IT1_Msk				(0x1 << TMR_TCON_IT1_Pos)
#define TMR_TCON_IE0_Pos				(1)
#define TMR_TCON_IE0_Msk				(0x1 << TMR_TCON_IE0_Pos)
#define TMR_TCON_IT0_Pos				(0)
#define TMR_TCON_IT0_Msk				(0x1 << TMR_TCON_IT0_Pos)
/*------CKCON-----------------------------------------------------*/
#define TMR_CKCON_WTSn_Pos				(6)
#define TMR_CKCON_WTSn_Msk				(0x3 << TMR_CKCON_WTSn_Pos)
#define TMR_CKCON_T1M_Pos				(4)
#define TMR_CKCON_T1M_Msk				(0x1 << TMR_CKCON_T1M_Pos)
#define TMR_CKCON_T0M_Pos				(3)
#define TMR_CKCON_T0M_Msk				(0x1 << TMR_CKCON_T0M_Pos)
/*------T2CON-----------------------------------------------------*/
#define TMR_T2CON_T2PS_Pos				(7)
#define TMR_T2CON_T2PS_Msk				(0x1 << TMR_T2CON_T2PS_Pos)
#define TMR_T2CON_I3FR_Pos				(6)
#define TMR_T2CON_I3FR_Msk				(0x1 << TMR_T2CON_I3FR_Pos)
#define TMR_T2CON_CAPES_Pos				(5)
#define TMR_T2CON_CAPES_Msk				(0x1 << TMR_T2CON_CAPES_Pos)
#define TMR_T2CON_T2Rn_Pos				(3)
#define TMR_T2CON_T2Rn_Msk				(0x3 << TMR_T2CON_T2Rn_Pos)
#define TMR_T2CON_T2CM_Pos				(2)
#define TMR_T2CON_T2CM_Msk				(0x1 << TMR_T2CON_T2CM_Pos)
#define TMR_T2CON_T2In_Pos				(0)
#define TMR_T2CON_T2In_Msk				(0x3 << TMR_T2CON_T2In_Pos)

/*------CCEN------------------------------------------------------*/
#define TMR_CCEN_CMn3_Pos				(6)
#define TMR_CCEN_CMn3_Msk				(0x3 << TMR_CCEN_CMn3_Pos)
#define TMR_CCEN_CMn2_Pos				(4)
#define TMR_CCEN_CMn2_Msk				(0x3 << TMR_CCEN_CMn2_Pos)
#define TMR_CCEN_CMn1_Pos				(2)
#define TMR_CCEN_CMn1_Msk				(0x3 << TMR_CCEN_CMn1_Pos)
#define TMR_CCEN_CMn0_Pos				(0)
#define TMR_CCEN_CMn0_Msk				(0x3 << TMR_CCEN_CMn0_Pos)

/*------T34MOD----------------------------------------------------*/
#define TMR_T34MOD_TR4_Pos				(7)
#define TMR_T34MOD_TR4_Msk				(0x1 << TMR_T34MOD_TR4_Pos)
#define TMR_T34MOD_T4M_Pos				(6)
#define TMR_T34MOD_T4M_Msk				(0x1 << TMR_T34MOD_T4M_Pos)
#define TMR_T34MOD_T4Mn_Pos				(4)
#define TMR_T34MOD_T4Mn_Msk				(0x3 << TMR_T34MOD_T4Mn_Pos)
#define TMR_T34MOD_TR3_Pos				(3)
#define TMR_T34MOD_TR3_Msk				(0x1 << TMR_T34MOD_TR3_Pos)
#define TMR_T34MOD_T3M_Pos				(2)
#define TMR_T34MOD_T3M_Msk				(0x1 << TMR_T34MOD_T3M_Pos)
#define TMR_T34MOD_T3Mn_Pos				(0)
#define TMR_T34MOD_T3Mn_Msk				(0x3 << TMR_T34MOD_T3Mn_Pos)

/*-----------------------------------------------------------------
**UART
------------------------------------------------------------------*/
/*------SCON0------------------------------------------------------*/
#define UART_SCON0_U0SMn_Pos			(6)
#define UART_SCON0_U0SMn_Msk			(0x3 << UART_SCON0_U0SMn_Pos)
#define UART_SCON0_U0SM2_Pos			(5)
#define UART_SCON0_U0SM2_Msk			(0x1 << UART_SCON0_U0SM2_Pos)
#define UART_SCON0_U0REN_Pos			(4)
#define UART_SCON0_U0REN_Msk			(0x1 << UART_SCON0_U0REN_Pos)
#define UART_SCON0_U0TB8_Pos			(3)
#define UART_SCON0_U0TB8_Msk			(0x1 << UART_SCON0_U0TB8_Pos)
#define UART_SCON0_U0RB8_Pos			(2)
#define UART_SCON0_U0RB8_Msk			(0x1 << UART_SCON0_U0RB8_Pos)
#define UART_SCON0_TI0_Pos				(1)
#define UART_SCON0_TI0_Msk				(0x1 << UART_SCON0_TI0_Pos)
#define UART_SCON0_RI0_Pos				(0)
#define UART_SCON0_RI0_Msk				(0x1 << UART_SCON0_RI0_Pos)
/*------SCON1------------------------------------------------------*/
#define UART_SCON1_U1SMn_Pos			(6)
#define UART_SCON1_U1SMn_Msk			(0x3 << UART_SCON1_U1SMn_Pos)
#define UART_SCON1_U1SM2_Pos			(5)
#define UART_SCON1_U1SM2_Msk			(0x1 << UART_SCON1_U1SM2_Pos)
#define UART_SCON1_U1REN_Pos			(4)
#define UART_SCON1_U1REN_Msk			(0x1 << UART_SCON1_U1REN_Pos)
#define UART_SCON1_U1TB8_Pos			(3)
#define UART_SCON1_U1TB8_Msk			(0x1 << UART_SCON1_U1TB8_Pos)
#define UART_SCON1_U1RB8_Pos			(2)
#define UART_SCON1_U1RB8_Msk			(0x1 << UART_SCON1_U1RB8_Pos)
#define UART_SCON1_TI1_Pos				(1)
#define UART_SCON1_TI1_Msk				(0x1 << UART_SCON1_TI1_Pos)
#define UART_SCON1_RI1_Pos				(0)
#define UART_SCON1_RI1_Msk				(0x1 << UART_SCON1_RI1_Pos)
/*------BRTCON-----------------------------------------------------*/
#define UART_BRTCON_BRTEN_Pos			(7)
#define UART_BRTCON_BRTEN_Msk			(0x1 << UART_BRTCON_BRTEN_Pos)
#define UART_BRTCON_BRTCKDIV_Pos		(0)
#define UART_BRTCON_BRTCKDIV_Msk		(0x7 << UART_BRTCON_BRTCKDIV_Pos)


/*-----------------------------------------------------------------
**System
------------------------------------------------------------------*/
/*------PCON------------------------------------------------------*/
#define SYS_PCON_SMOD0_Pos			(7)
#define SYS_PCON_SMOD0_Msk			(0x1 << SYS_PCON_SMOD0_Pos)
#define SYS_PCON_SMOD1_Pos			(6)
#define SYS_PCON_SMOD1_Msk			(0x1 << SYS_PCON_SMOD1_Pos)
#define SYS_PCON_SWE_Pos			(2)
#define SYS_PCON_SWE_Msk			(0x1 << SYS_PCON_SWE_Pos)
#define SYS_PCON_STOP_Pos			(1)
#define SYS_PCON_STOP_Msk			(0x1 << SYS_PCON_STOP_Pos)
#define SYS_PCON_IDLE_Pos			(0)
#define SYS_PCON_IDLE_Msk			(0x1 << SYS_PCON_IDLE_Pos)

/*------FUNCCR----------------------------------------------------*/
#define SYS_FUNCCR_UART1_PORTS_Pos	(5)
#define SYS_FUNCCR_UART1_PORTS_Msk	(0x1 << SYS_FUNCCR_UART1_PORTS_Pos)
#define SYS_FUNCCR_I2C_PORTS_Pos	(4)
#define SYS_FUNCCR_I2C_PORTS_Msk	(0x1 << SYS_FUNCCR_I2C_PORTS_Pos)
#define SYS_FUNCCR_UART1_CKS1_Pos	(3)
#define SYS_FUNCCR_UART1_CKS1_Msk	(0x1 << SYS_FUNCCR_UART1_CKS1_Pos)
#define SYS_FUNCCR_UART0_CKS1_Pos	(2)
#define SYS_FUNCCR_UART0_CKS1_Msk	(0x1 << SYS_FUNCCR_UART0_CKS1_Pos)
#define SYS_FUNCCR_UART1_CKS0_Pos	(1)
#define SYS_FUNCCR_UART1_CKS0_Msk	(0x1 << SYS_FUNCCR_UART1_CKS0_Pos)
#define SYS_FUNCCR_UART0_CKS0_Pos	(0)
#define SYS_FUNCCR_UART0_CKS0_Msk	(0x1 << SYS_FUNCCR_UART0_CKS0_Pos)

/*------SCKSEL----------------------------------------------------*/
//#define SYS_SCKSEL_SEL_Pos			(4)
//#define SYS_SCKSEL_SEL_Msk			(0x1 << SYS_SCKSEL_SEL_Pos)
//#define SYS_SCKSEL_WRITE_Pos		(3)
//#define SYS_SCKSEL_WRITE_Msk		(0x1 << SYS_SCKSEL_WRITE_Pos)
//#define SYS_SCKSEL_CKSEL_Pos		(0)
//#define SYS_SCKSEL_CKSEL_Msk		(0x7 << SYS_SCKSEL_CKSEL_Pos)
/*------CKSTAU----------------------------------------------------*/
//#define SYS_CKSTAU_LSI_F_Pos		(7)
//#define SYS_CKSTAU_LSI_F_Msk		(0x1 << SYS_CKSTAU_LSI_F_Pos)
//#define SYS_CKSTAU_LSE_F_Pos		(6)
//#define SYS_CKSTAU_LSE_F_Msk		(0x1 << SYS_CKSTAU_LSE_F_Pos)
//#define SYS_CKSTAU_HSE_F_Pos		(5)
//#define SYS_CKSTAU_HSE_F_Msk		(0x1 << SYS_CKSTAU_HSE_F_Pos)
//#define SYS_CKSTAU_HSI_F_Pos		(4)
//#define SYS_CKSTAU_HSI_F_Msk		(0x1 << SYS_CKSTAU_HSI_F_Pos)
//#define SYS_CKSTAU_LSI_E_Pos		(3)
//#define SYS_CKSTAU_LSI_E_Msk		(0x1 << SYS_CKSTAU_LSI_E_Pos)
//#define SYS_CKSTAU_LSE_E_Pos		(2)
//#define SYS_CKSTAU_LSE_E_Msk		(0x1 << SYS_CKSTAU_LSE_E_Pos)
//#define SYS_CKSTAU_HSE_E_Pos		(1)
//#define SYS_CKSTAU_HSE_E_Msk		(0x1 << SYS_CKSTAU_HSE_E_Pos)
//#define SYS_CKSTAU_HSI_E_Pos		(0)
//#define SYS_CKSTAU_HSI_E_Msk		(0x1 << SYS_CKSTAU_HSI_E_Pos)


/*------WKTSET----------------------------------------------------*/
//#define SYS_WKTSET_WUEN_Pos			(7)
//#define SYS_WKTSET_WUEN_Msk			(0x1 << SYS_WKTSET_WUEN_Pos)
//#define SYS_WKTSET_XTCNTEN_Pos		(6)
//#define SYS_WKTSET_XTCNTEN_Msk		(0x1 << SYS_WKTSET_XTCNTEN_Pos)
//#define SYS_WKTSET_XTSEL_Pos		(5)
//#define SYS_WKTSET_XTSEL_Msk		(0x1 << SYS_WKTSET_XTSEL_Pos)
//#define SYS_WKTSET_XTINE_Pos		(1)
//#define SYS_WKTSET_XTINE_Msk		(0x1 << SYS_WKTSET_XTINE_Pos)
//#define SYS_WKTSET_XTINF_Pos		(0)
//#define SYS_WKTSET_XTINF_Msk		(0x1 << SYS_WKTSET_XTINF_Pos)



/*-----------------------------------------------------------------
**WDT
------------------------------------------------------------------*/
/*------WDCON-----------------------------------------------------*/
#define WDT_WDCON_SWRST_Pos			(7)
#define WDT_WDCON_SWRST_Msk			(0x1 << WDT_WDCON_SWRST_Pos)
#define WDT_WDCON_PORF_Pos			(6)
#define WDT_WDCON_PORF_Msk			(0x1 << WDT_WDCON_PORF_Pos)
#define WDT_WDCON_WDTIF_Pos			(3)
#define WDT_WDCON_WDTIF_Msk			(0x1 << WDT_WDCON_WDTIF_Pos)
#define WDT_WDCON_WDTRF_Pos			(2)
#define WDT_WDCON_WDTRF_Msk			(0x1 << WDT_WDCON_WDTRF_Pos)
#define WDT_WDCON_WDTRE_Pos			(1)
#define WDT_WDCON_WDTRE_Msk			(0x1 << WDT_WDCON_WDTRE_Pos)
#define WDT_WDCON_WDTCLR_Pos		(0)
#define WDT_WDCON_WDTCLR_Msk		(0x1 << WDT_WDCON_WDTCLR_Pos)
/*-----------------------------------------------------------------
**I2C
------------------------------------------------------------------*/
/*------I2CMCR----------------------------------------------------*/
#define I2C_I2CMCR_RSTS_Pos			(7)
#define I2C_I2CMCR_RSTS_Msk			(0x1 << I2C_I2CMCR_RSTS_Pos)
#define I2C_I2CMCR_ACK_Pos			(3)
#define I2C_I2CMCR_ACK_Msk			(0x1 << I2C_I2CMCR_ACK_Pos)
#define I2C_I2CMCR_STOP_Pos			(2)
#define I2C_I2CMCR_STOP_Msk			(0x1 << I2C_I2CMCR_STOP_Pos)
#define I2C_I2CMCR_START_Pos		(1)
#define I2C_I2CMCR_START_Msk		(0x1 << I2C_I2CMCR_START_Pos)
#define I2C_I2CMCR_RUN_Pos			(0)
#define I2C_I2CMCR_RUN_Msk			(0x1 << I2C_I2CMCR_RUN_Pos)
/*------I2CMSR----------------------------------------------------*/
#define I2C_I2CMSR_I2CMIF_Pos		(7)
#define I2C_I2CMSR_I2CMIF_Msk		(0x1 << I2C_I2CMSR_I2CMIF_Pos)
#define I2C_I2CMSR_BUS_BUSY_Pos		(6)
#define I2C_I2CMSR_BUS_BUSY_Msk		(0x1 << I2C_I2CMSR_BUS_BUSY_Pos)
#define I2C_I2CMSR_IDLE_Pos			(5)
#define I2C_I2CMSR_IDLE_Msk			(0x1 << I2C_I2CMSR_IDLE_Pos)
#define I2C_I2CMSR_ARB_LOST_Pos		(4)
#define I2C_I2CMSR_ARB_LOST_Msk		(0x1 << I2C_I2CMSR_ARB_LOST_Pos)
#define I2C_I2CMSR_DATA_ACK_Pos		(3)
#define I2C_I2CMSR_DATA_ACK_Msk		(0x1 << I2C_I2CMSR_DATA_ACK_Pos)
#define I2C_I2CMSR_ADD_ACK_Pos		(2)
#define I2C_I2CMSR_ADD_ACK_Msk		(0x1 << I2C_I2CMSR_ADD_ACK_Pos)
#define I2C_I2CMSR_ERROR_Pos		(1)
#define I2C_I2CMSR_ERROR_Msk		(0x1 << I2C_I2CMSR_ERROR_Pos)
#define I2C_I2CMSR_BUSY_Pos			(0)
#define I2C_I2CMSR_BUSY_Msk		(0x1 << I2C_I2CMSR_BUSY_Pos)
/*------I2CMSA----------------------------------------------------*/
#define I2C_I2CMSA_SAn_Pos			(1)
#define I2C_I2CMSA_SAn_Msk			(0x7F << I2C_I2CMSA_SAn_Pos)
#define I2C_I2CMSA_RS_Pos			(0)
#define I2C_I2CMSA_RS_Msk			(0x1 << I2C_I2CMSA_RS_Pos)
/*------I2CSCR----------------------------------------------------*/
#define I2C_I2CSCR_RSTS_Pos			(7)
#define I2C_I2CSCR_RSTS_Msk			(0x1 << I2C_I2CSCR_RSTS_Pos)
#define I2C_I2CSCR_DA_Pos			(0)
#define I2C_I2CSCR_DA_Msk			(0x1 << I2C_I2CSCR_DA_Pos)
/*------I2CSSR----------------------------------------------------*/
#define I2C_I2CSSR_SENDFIN_Pos		(2)
#define I2C_I2CSSR_SENDFIN_Msk		(0x1 << I2C_I2CSCR_RSTS_Pos)
#define I2C_I2CSSR_TREQ_Pos			(1)
#define I2C_I2CSSR_TREQ_Msk			(0x1 << I2C_I2CSSR_TREQ_Pos)
#define I2C_I2CSSR_RREQ_Pos			(0)
#define I2C_I2CSSR_RREQ_Msk			(0x1 << I2C_I2CSSR_RREQ_Pos)
/*-----------------------------------------------------------------
**BUZZER
------------------------------------------------------------------*/
/*------BUZCON----------------------------------------------------*/
#define BUZZER_BUZCON_BUZEN_Pos		(7)
#define BUZZER_BUZCON_BUZEN_Msk		(0x1 << BUZZER_BUZCON_BUZEN_Pos)
#define BUZZER_BUZCON_BUZCKS_Pos	(0)
#define BUZZER_BUZCON_BUZCKS_Msk	(0x3 << BUZZER_BUZCON_BUZCKS_Pos)
/*-----------------------------------------------------------------
**FLASH
------------------------------------------------------------------*/
/*------FLASH----------------------------------------------------*/
#define FLASH_MCTRL_MERR_Pos		(5)
#define FLASH_MCTRL_MERR_Msk		(0x1 << FLASH_MCTRL_MERR_Pos)
#define FLASH_MCTRL_MREG_Pos		(4)
#define FLASH_MCTRL_MREG_Msk		(0x1 << FLASH_MCTRL_MREG_Pos)
#define FLASH_MCTRL_MMODE_Pos		(2)
#define FLASH_MCTRL_MMODE_Msk		(0x3 << FLASH_MCTRL_MMODE_Pos)
#define FLASH_MCTRL_MSTART_Pos		(0)
#define FLASH_MCTRL_MSTART_Msk		(0x1 << FLASH_MCTRL_MSTART_Pos)
/*-----------------------------------------------------------------
**SPI
------------------------------------------------------------------*/
/*------SPCR------------------------------------------------------*/
#define SPI_SPCR_SPEN_Pos			(6)
#define SPI_SPCR_SPEN_Msk			(0x1 << SPI_SPCR_SPEN_Pos)
#define SPI_SPCR_SPR2_Pos			(5)
#define SPI_SPCR_SPR2_Msk			(0x1 << SPI_SPCR_SPR2_Pos)
#define SPI_SPCR_MSTR_Pos			(4)
#define SPI_SPCR_MSTR_Msk			(0x1 << SPI_SPCR_MSTR_Pos)
#define SPI_SPCR_CPOL_Pos			(3)
#define SPI_SPCR_CPOL_Msk			(0x1 << SPI_SPCR_CPOL_Pos)
#define SPI_SPCR_CPHA_Pos			(2)
#define SPI_SPCR_CPHA_Msk			(0x1 << SPI_SPCR_CPHA_Pos)
#define SPI_SPCR_SPRn_Pos			(0)
#define SPI_SPCR_SPRn_Msk			(0x3 << SPI_SPCR_SPRn_Pos)

/*------SPSR------------------------------------------------------*/
#define SPI_SPSR_SPISIF_Pos			(7)
#define SPI_SPSR_SPISIF_Msk			(0x1 << SPI_SPSR_SPISIF_Pos)
#define SPI_SPSR_WCOL_Pos			(6)
#define SPI_SPSR_WCOL_Msk			(0x1 << SPI_SPSR_WCOL_Pos)
#define SPI_SPSR_SSICS_Pos			(1)
#define SPI_SPSR_SSICS_Msk			(0x1 << SPI_SPSR_SSICS_Pos)
#define SPI_SPSR_SSCEN_Pos			(0)
#define SPI_SPSR_SSCEN_Msk			(0x1 << SPI_SPSR_SSCEN_Pos)

/*------SSCR------------------------------------------------------*/
#define SPI_SSCR_SSO7_Pos			(7)
#define SPI_SSCR_SSO7_Msk			(0x1 << SPI_SSCR_SSO7_Pos)
#define SPI_SSCR_SSO6_Pos			(6)
#define SPI_SSCR_SSO6_Msk			(0x1 << SPI_SSCR_SSO6_Pos)
#define SPI_SSCR_SSO5_Pos			(5)
#define SPI_SSCR_SSO5_Msk			(0x1 << SPI_SSCR_SSO5_Pos)
#define SPI_SSCR_SSO3_Pos			(3)
#define SPI_SSCR_SSO3_Msk			(0x1 << SPI_SSCR_SSO3_Pos)

/*-----------------------------------------------------------------
**жȼģ Priority Module Number
------------------------------------------------------------------*/
typedef enum  en_Priority_Module{
	IRQ_EXINT0	=0,
	IRQ_TMR0	=1,
	IRQ_EXINT1	=2,
	IRQ_TMR1	=3,
	IRQ_UART0	=4,
	IRQ_TMR2	=5,
	IRQ_UART1	=6,	
	IRQ_P0		=8,
	IRQ_P1		=9,
	IRQ_P2		=10,
	IRQ_P3		=11,	

	IRQ_TMR3	=16,
	IRQ_TMR4	=17,
	IRQ_PWM		=19,
	IRQ_ADC 	=20,
	IRQ_WDT  	=21,
	IRQ_I2C  	=22,
	IRQ_SPI  	=23,
}en_Priority_Module_t;

/*-----------------------------------------------------------------
**жȼ IRQPriority
------------------------------------------------------------------*/
#define  IRQ_PRIORITY_LOW		(0x00)
#define  IRQ_PRIORITY_HIGH		(0x01)	

/********************************************************************************
 ** \brief	 IRQ_SET_PRIORITY
 **			 жȼ
 ** \param [in] none
 ** \return  none
 ******************************************************************************/
#define  IRQ_SET_PRIORITY(IRQ_Module, IRQPriority)  do{\
														if(IRQ_Module <8)\
														{\
															IP &= ~(1<< IRQ_Module);\
															IP |=(IRQPriority<< IRQ_Module);\
														}\
														else if(IRQ_Module <16)\
														{\
															EIP1 &= ~(1<< (IRQ_Module-8));\
															EIP1 |= (IRQPriority<< (IRQ_Module-8));\
														}\
														else if(IRQ_Module <24)\
														{\
															EIP2 &= ~(1<< (IRQ_Module-16));\
															EIP2 |=(IRQPriority<< (IRQ_Module-16));\
														}\
													}while(0)

/********************************************************************************
 ** \brief	 IRQ_ALL_ENABLE
 **			 ʹж
 ** \param [in] none
 ** \return  none
 ******************************************************************************/
#define  IRQ_ALL_ENABLE()		do{\
									IE |= (IRQ_IE_EA_Msk);\
								  }while(0)
/********************************************************************************
 ** \brief	 IRQ_ALL_DISABLE
 **			 رж
 ** \param [in] none
 ** \return  none
 ******************************************************************************/
#define  IRQ_ALL_DISABLE()		do{\
									IE &= (~IRQ_IE_EA_Msk);\
								  }while(0)

	
//----------------------------------------------------
//----------------------------------------------------
/*   interrupt vector all 23  */
#define         INT0_VECTOR		0
#define         TIMER0_VECTOR	1
#define         INT1_VECTOR		2
#define         TIMER1_VECTOR   3
#define         UART0_VECTOR    4
#define         TIMER2_VECTOR	5
#define         UART1_VECTOR    6
#define         P0EI_VECTOR		7
#define         P1EI_VECTOR		8
#define         P2EI_VECTOR		9
#define         P3EI_VECTOR		10

#define         TIMER3_VECTOR	15
#define         TIMER4_VECTOR	16
#define         PWM_VECTOR		18
#define         ADC_VECTOR   	19
#define         WDT_VECTOR      20
#define         I2C_VECTOR		21
#define         SPI_VECTOR		22

//----------------------------------------------------	

/*****************************************************************************/
/* Global variable declarations ('extern', definition in C source) */
/*****************************************************************************/
extern  uint32_t  SystemClock;
/*****************************************************************************/
/* Global function prototypes ('extern', definition in C source) */
/*****************************************************************************/
#include "adc.h"
#include "buzzer.h"
#include "epwm.h"
#include "extint.h"
#include "flash.h"
#include "gpio.h"
#include "i2c.h"
#include "spi.h"
#include "system.h"
#include "timer.h"
#include "uart.h"
#include "wdt.h"
#endif /*_CMS8S5880XX_H_*/